import { LogLevel } from '@genesislcap/foundation-logger';
import { NotificationStructure, Banner, Dialog, Toast, Snackbar } from './types';
/**
 * NotificationBuilder to build NotificationStructure
 * @public
 */
export declare class NotificationBuilder {
    private title;
    private body;
    private createdAt;
    private logLevel;
    private alert;
    private toast;
    private banner;
    private snackbar;
    private dialog;
    /**
     * Add title to notification
     * @public
     * @param title - string
     * @returns
     */
    withTitle(title: string): NotificationBuilder;
    /**
     * Add body details to notification
     * @public
     * @param body - string
     * @returns
     */
    withBody(body: string): NotificationBuilder;
    /**
     * Add the creation date to notification
     * @public
     * @param createdAt - Date
     * @returns
     */
    withCreatedAt(createdAt: Date): NotificationBuilder;
    /**
     * Add log level to notification
     * @public
     * @returns
     */
    withLogLevel(logLevel: LogLevel): NotificationBuilder;
    /**
     * Add alert to notification
     * @public
     * @param alert - boolean
     * @returns
     */
    withAlert(alert: boolean): NotificationBuilder;
    /**
     * Add toast to notification
     * @public
     * @param notification - {@link Toast}
     * @returns
     */
    withToast(toast: Toast): NotificationBuilder;
    /**
     * Add banner to notification
     * @public
     * @param banner - {@link Banner}
     * @returns
     */
    withBanner(banner: Banner): NotificationBuilder;
    /**
     * Add snackbar to notification
     * @public
     * @param snackbar - {@link Snackbar}
     * @returns
     */
    withSnackbar(snackbar: Snackbar): NotificationBuilder;
    /**
     * Add dialog to notification
     * @public
     * @param dialog - {@link Dialog}
     * @returns
     */
    withDialog(dialog: Dialog): NotificationBuilder;
    /**
     * Build NotificationStructure
     * @public
     * @returns
     */
    build(): NotificationStructure;
}
/**
 * Returns a new NotificationBuilder instance
 * @public
 */
export declare const getNotificationBuilder: () => NotificationBuilder;
//# sourceMappingURL=notification-builder.d.ts.map