import { Toast, ToastPosition, NotificationType, NotificationDataRow, ToastButton } from '../types';
/**
 * @public
 */
export declare class ToastBuilder {
    private position;
    private autoClose;
    private closeTimeout;
    private type;
    private details;
    private buttons;
    /**
     * Add position to toast
     * @public
     * @param position - {@link ToastPosition}
     * @returns
     */
    withPosition(position: ToastPosition): ToastBuilder;
    /**
     * Add auto close to notification
     * @public
     * @param autoClose - boolean
     * @returns
     */
    withAutoClose(autoClose: boolean): ToastBuilder;
    /**
     * Add close timeout to notification
     * @public
     * @param closeTimeout - number
     * @returns
     */
    withCloseTimeout(closeTimeout: number): ToastBuilder;
    /**
     * Add type to notification, if the type is anything other than 'warning' or 'success' do not add it
     * @public
     * @param type - {@link NotificationType}
     * @returns
     */
    withType(type: NotificationType): ToastBuilder;
    /**
     * Add details data to notifications
     * @public
     * @param details - NotificationDataRow
     * @returns
     */
    withDetails(details: NotificationDataRow): ToastBuilder;
    /**
     * Add buttons to notifications
     * @public
     * @param buttons - ToastButton[]
     * @returns
     */
    withButtons(buttons: ToastButton[]): ToastBuilder;
    /**
     * Build notification
     * @returns Toast
     */
    build(): Toast;
}
/**
 * Get notification builder instance
 * @public
 */
export declare const getToastBuilder: () => ToastBuilder;
//# sourceMappingURL=toast-builder.d.ts.map