/**
 * BannerBuilder
 * @public
 */
export class BannerBuilder {
    /**
     * Add dismissing action to Banner
     * @public
     * @param dismissingAction - {@link DismissingAction}
     * @returns
     */
    withDismissingAction(dismissingAction) {
        this.dismissingAction = dismissingAction;
        return this;
    }
    /**
     * Add confirming action to Banner
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     */
    withConfirmingAction(confirmingAction) {
        if (!this.confirmingActions) {
            this.confirmingActions = [];
        }
        this.confirmingActions.push(confirmingAction);
        return this;
    }
    /**
     * Build Banner
     * @public
     * @returns Banner
     */
    build() {
        let banner = {};
        if (this.dismissingAction) {
            banner = Object.assign({ dismissingAction: this.dismissingAction }, banner);
        }
        if (this.confirmingActions) {
            banner = Object.assign({ confirmingActions: this.confirmingActions }, banner);
        }
        return banner;
    }
}
/**
 * Get banner builder instance
 * @public
 */
export const getBannerBuilder = () => new BannerBuilder();
