/**
 * DialogBuilder class
 * @public
 */
export class DialogBuilder {
    /**
     * Add dismissing action to Dialog
     * @public
     * @param dismissingAction - {@link DismissingAction}
     * @returns
     */
    withDismissingAction(dismissingAction) {
        this.dismissingAction = dismissingAction;
        return this;
    }
    /**
     * Add confirming action to Dialog
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     */
    withConfirmingAction(confirmingAction) {
        if (!this.confirmingActions) {
            this.confirmingActions = [];
        }
        this.confirmingActions.push(confirmingAction);
        return this;
    }
    /**
     * Build Dialog
     * @public
     * @returns Dialog
     */
    build() {
        let dialog = {};
        if (this.dismissingAction) {
            dialog = Object.assign({ dismissingAction: this.dismissingAction }, dialog);
        }
        if (this.confirmingActions) {
            dialog = Object.assign({ confirmingActions: this.confirmingActions }, dialog);
        }
        return dialog;
    }
}
/**
 * Returns an instance of DialogBuilder
 * @public
 */
export const getDialogBuilder = () => new DialogBuilder();
