import { createLogger } from '@genesislcap/foundation-logger';
import { showBanner } from './banner';
import { showDialog } from './dialog';
import { getNotificationDetails, getLoglevel } from './notification-util';
import { showSnackbar } from './snackbar';
import { showToast } from './toast';
const logger = createLogger('foundation-notifications');
const notificationTypeToComponentMap = {
    alert: (notificationStructure) => {
        alert(getNotificationDetails(notificationStructure));
    },
    toast: showToast,
    dialog: showDialog,
    snackbar: showSnackbar,
    banner: showBanner,
};
/**
 * Shows the notificationStructure in the appropriate component
 * @public
 * @param notificationStructure - The NotificationStructure object
 * @param tagName - The tag name to create prefix for the design system provider *
 * @param notificationBoundary - The notificationStructure boundary element
 * @returns
 * */
export const showNotification = (notificationStructure, tagName, notificationBoundary) => {
    logger.log({
        message: getNotificationDetails(notificationStructure),
        level: getLoglevel(notificationStructure),
    });
    const keys = Object.keys((notificationStructure === null || notificationStructure === void 0 ? void 0 : notificationStructure.config) || {});
    keys.forEach((key) => {
        if (notificationTypeToComponentMap[key]) {
            notificationTypeToComponentMap[key](notificationStructure, tagName, notificationBoundary);
        }
    });
};
